# Platypus 

A graph library for sparse graph algorithms.

## Usage

Install the library using pip:

```
pip install platypus-graph
```

Once installed you can include the library using `import platypus` (note the module name).

